summaryrefslogtreecommitdiffstats
path: root/akregator/src/tagaction.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'akregator/src/tagaction.cpp')
-rw-r--r--akregator/src/tagaction.cpp26
1 files changed, 13 insertions, 13 deletions
diff --git a/akregator/src/tagaction.cpp b/akregator/src/tagaction.cpp
index 4222bf2d7..eba476c51 100644
--- a/akregator/src/tagaction.cpp
+++ b/akregator/src/tagaction.cpp
@@ -30,8 +30,8 @@
#include <kdebug.h>
#include <kpopupmenu.h>
-#include <qmap.h>
-#include <qpopupmenu.h>
+#include <tqmap.h>
+#include <tqpopupmenu.h>
namespace Akregator {
@@ -40,17 +40,17 @@ class TagAction::TagActionPrivate
{
public:
Tag tag;
- //QMap<int, QPopupMenu*> idToPopup;
- //QMap<QPopupMenu*, int> popupToId;
+ //TQMap<int, TQPopupMenu*> idToPopup;
+ //TQMap<TQPopupMenu*, int> popupToId;
};
-TagAction::TagAction(const Tag& tag, const QObject *receiver, const char *slot, QObject *parent)
-//KAction (const QString &text, const KShortcut &cut, const QObject *receiver, const char *slot, QObject *parent, const char *name=0)
+TagAction::TagAction(const Tag& tag, const TQObject *receiver, const char *slot, TQObject *parent)
+//KAction (const TQString &text, const KShortcut &cut, const TQObject *receiver, const char *slot, TQObject *parent, const char *name=0)
: KToggleAction(tag.name(), KShortcut(), 0, 0, parent), d(new TagActionPrivate)
{
d->tag = tag;
- connect(this, SIGNAL(toggled(const Tag&, bool)), receiver, slot);
- connect(this, SIGNAL(toggled(bool)), this, SLOT(slotToggled(bool)));
+ connect(this, TQT_SIGNAL(toggled(const Tag&, bool)), receiver, slot);
+ connect(this, TQT_SIGNAL(toggled(bool)), this, TQT_SLOT(slotToggled(bool)));
}
TagAction::~TagAction()
@@ -65,11 +65,11 @@ Tag TagAction::tag() const
}
/*
-void TagAction::unplug(QWidget* widget)
+void TagAction::unplug(TQWidget* widget)
{
KToggleAction::unplug(widget);
- QPopupMenu* popup = ::qt_cast<QPopupMenu *>(widget);
+ TQPopupMenu* popup = ::qt_cast<TQPopupMenu *>(widget);
if (popup)
{
d->idToPopup.remove(d->popupToId[popup]);
@@ -78,9 +78,9 @@ void TagAction::unplug(QWidget* widget)
}*/
/*
-int TagAction::plug(QWidget* widget, int index)
+int TagAction::plug(TQWidget* widget, int index)
{
- QPopupMenu* popup = ::qt_cast<QPopupMenu *>( widget );
+ TQPopupMenu* popup = ::qt_cast<TQPopupMenu *>( widget );
if (!popup)
{
kdWarning() << "Can not plug KToggleAction in " << widget->className() << endl;
@@ -93,7 +93,7 @@ int TagAction::plug(QWidget* widget, int index)
int id = popup->insertItem(TagMenuItem::checkBoxIconSet(isChecked(), popup->colorGroup()), item, -1, index);
- popup->connectItem (id, this, SLOT(slotActivated()));
+ popup->connectItem (id, this, TQT_SLOT(slotActivated()));
d->popupToId[popup] = id;
d->idToPopup[id] = popup;